@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.2   2017/09/17
+ * Version: 0.2.3   2018/04/01
  */
 
 #include "caitsith.h"
@@ -1764,12 +1764,18 @@ int cs_socket_listen_permission(struct socket *sock)
 
 	if (!family || (type != SOCK_STREAM && type != SOCK_SEQPACKET))
 		return 0;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 17, 0)
 	{
 		const int error = sock->ops->getname(sock, (struct sockaddr *)
 						     &addr, &addr_len, 0);
 		if (error)
 			return error;
 	}
+#else
+	addr_len = sock->ops->getname(sock, (struct sockaddr *) &addr, 0);
+	if (addr_len < 0)
+		return addr_len;
+#endif
 	if (family == PF_INET || family == PF_INET6)
 		address.operation = CS_MAC_INET_STREAM_LISTEN;
 	else if (type == SOCK_STREAM)
@@ -1923,6 +1929,7 @@ int cs_socket_post_accept_permission(struct socket *sock,
 
 	if (!family || (type != SOCK_STREAM && type != SOCK_SEQPACKET))
 		return 0;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 17, 0)
 	{
 		const int error = newsock->ops->getname(newsock,
 							(struct sockaddr *)
@@ -1930,6 +1937,12 @@ int cs_socket_post_accept_permission(struct socket *sock,
 		if (error)
 			return error;
 	}
+#else
+	addr_len = newsock->ops->getname(newsock, (struct sockaddr *) &addr,
+					 2);
+	if (addr_len < 0)
+		return addr_len;
+#endif
 	if (family == PF_INET || family == PF_INET6)
 		address.operation = CS_MAC_INET_STREAM_ACCEPT;
 	else if (type == SOCK_STREAM)
