@@ -28,6 +28,9 @@
 #ifndef CONFIG_MODULES
 #error You must choose CONFIG_MODULES=y for building this module.
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 26)
+#include <linux/kallsyms.h>
+#endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 1, 0) && !defined(SECURITY_NAME_MAX)
 #include <linux/lsm_hooks.h>
